@@ -430,10 +430,6 @@ class CfnIPSet(
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waf-ipset-ipsetdescriptors.html
         '''
 
-        @builtins.staticmethod
-        def __jsii_proxy_class__() -> typing.Type["_IPSetDescriptorPropertyProxy"]:
-            return _IPSetDescriptorPropertyProxy
-
         @builtins.property # type: ignore[misc]
         @jsii.member(jsii_name="type")
         def type(self) -> builtins.str:
@@ -478,6 +474,9 @@ class CfnIPSet(
             '''
             return typing.cast(builtins.str, jsii.get(self, "value"))
 
+    # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+    typing.cast(typing.Any, IPSetDescriptorProperty).__jsii_proxy_class__ = lambda : _IPSetDescriptorPropertyProxy
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-waf.CfnIPSetProps",
